@@ -10,12 +10,13 @@ from jc import appdirs
 from jc import utils
 
 
-__version__ = '1.25.3'
+__version__ = '1.25.5'
 
 parsers: List[str] = [
     'acpi',
     'airport',
     'airport-s',
+    'amixer',
     'apt-cache-show',
     'apt-get-sqq',
     'arp',
@@ -75,6 +76,7 @@ parsers: List[str] = [
     'iostat',
     'iostat-s',
     'ip-address',
+    'ipconfig',
     'iptables',
     'ip-route',
     'iw-scan',
@@ -107,6 +109,7 @@ parsers: List[str] = [
     'openvpn',
     'os-prober',
     'os-release',
+    'pacman',
     'passwd',
     'path',
     'path-list',
@@ -224,6 +227,7 @@ parsers: List[str] = [
     'vmstat-s',
     'w',
     'wc',
+    'wg-show',
     'who',
     'x509-cert',
     'x509-csr',
